# DARTFlo
DARTFlo (Discrete Adjoint for Rapid Transonic Flows, abbreviated as DART) is an open-source C++/python, unstructured finite-element, full potential solver, developed at the University of Liège by Adrien Crovato with the active collaboration of Romain Boman, and under the supervision of Vincent Terrapon and Grigorios Dimitriadis, during the academic years 2018-2022.  
DART is currently capable of rapidly solving steady transonic flows on arbitrary configurations, ranging from 2D airfoils to 3D full aircraft (without engine), as well as calculating the flow gradients using a discrete adjoint method. Furthemore, the code is interfaced with [CUPyDO](https://github.com/ulgltas/CUPyDO) and [openMDAO](https://openmdao.org/) so that aeroelastic computations and optimization can be easily carried out.

![](/dox/title.png)

## Main features
* Cross platform (Windows and Unix) C++/python code
* Physical model
  - unstructured meshes for 2D and 3D geometries using [gmsh](https://gmsh.info/)
  - steady transonic flows
  - viscous-inviscid interaction (2D only)
* Numerical methods
  - linear algrebra using [Eigen](http://eigen.tuxfamily.org/)
  - direct (forward) and adjoint (backward) modes
  - nonlinear Newton solver with Bank&Rose line search
  - linear [Intel MKL](https://software.intel.com/content/www/us/en/develop/tools/oneapi/components/onemkl.html) PARDISO, Eigen GMRES or [MUMPS](http://mumps.enseeiht.fr/) solvers
* Interfaced with
  - [VTK](https://vtk.org/)
  - [CUPyDO](https://github.com/ulgltas/CUPyDO)
  - [openMDAO](https://openmdao.org/)

## Documentation
Detailed instructions for building and using the code, as well as references to theory manuals and scientific articles can be found in the [wiki](https://gitlab.uliege.be/am-dept/dartflo/wikis/home).
